@@ -7,7 +7,7 @@ class TextDiffEngine:
     The API compares two texts and highlights changes, including added, deleted, and moved blocks.
     """
 
-    API_URL = "https://formamind.com/api/diffengine/compare/"
+    API_URL = "https://www.api.formamind.com/api/diffengine/compare/"
 
     def __init__(self, api_key):
         """
@@ -29,14 +29,16 @@ class TextDiffEngine:
         payload = {
             "old_text": old_text,
             "new_text": new_text,
-            "output_format": output_format
+            "output_format": output_format,
         }
         headers = {
             "X-DiffEngine-Secret": f"{self.api_key}",
-            "Content-Type": "application/json"
+            "Content-Type": "application/json",
         }
 
-        response = requests.post(self.API_URL, json=payload, headers=headers, timeout=30)
+        response = requests.post(
+            self.API_URL, json=payload, headers=headers, timeout=31
+        )
         response.raise_for_status()
 
         return response.json()
